package com.ruoyi.system.service;

import com.ruoyi.system.domain.visitor.VisitorManage;

import java.util.List;


/**
 * 来访管理Service接口
 * 
 * @author boman
 * @date 2025-02-14
 */
public interface IVisitorManageService 
{
    /**
     * 查询来访管理
     * 
     * @param visitorManageId 来访管理主键
     * @return 来访管理
     */
    public VisitorManage selectVisitorManageByVisitorManageId(Long visitorManageId);

    /**
     * 查询来访管理列表
     * 
     * @param visitorManage 来访管理
     * @return 来访管理集合
     */
    public List<VisitorManage> selectVisitorManageList(VisitorManage visitorManage);

    /**
     * 新增来访管理
     * 
     * @param visitorManage 来访管理
     * @return 结果
     */
    public int insertVisitorManage(VisitorManage visitorManage);

    /**
     * 修改来访管理
     * 
     * @param visitorManage 来访管理
     * @return 结果
     */
    public int updateVisitorManage(VisitorManage visitorManage);

    /**
     * 批量删除来访管理
     * 
     * @param visitorManageIds 需要删除的来访管理主键集合
     * @return 结果
     */
    public int deleteVisitorManageByVisitorManageIds(Long[] visitorManageIds);

    /**
     * 删除来访管理信息
     * 
     * @param visitorManageId 来访管理主键
     * @return 结果
     */
    public int deleteVisitorManageByVisitorManageId(Long visitorManageId);
}
